==> wpackagist-plugin-styles-layouts-material-design-4.1.zip: includes/list.php <==
<?php

/***************************************** for list field **************************************/

if ( $field->type == 'list' ) {


	$content_xpath = new DomXPath($dom);

	$list_groups = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_list_group ')]");

	$validation_errors = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' validation_message ')]");
	$validation_error_class = '';

	foreach ( $validation_errors as $validation_error ) {
		$validation_error->setAttribute( 'class', $validation_error->getAttribute( 'class' ) . ' mdc-text-field-helper-text mdc-text-field-helper-text--persistent mdc-text-field-helper-text--validation-msg' );

		// error present then set varialbe
		$validation_error_class = 'mdc-text-field--invalid';
	}

	foreach( $list_groups as $list_group ){
		$cell_inputs = $list_group->getElementsByTagName( 'input' );
		
		foreach( $cell_inputs as $cell_input ){
			$item_container = $cell_input->parentNode;
			$outer_div = $dom->createElement( 'div' );
				$outer_div->setAttribute( 'data-mdc-auto-init', 'MDCTextField' );
				$item_container->appendChild( $outer_div );

				

			if( $type === 'filled' ){
				
				$outer_div->setAttribute( 'class', $outer_div->getAttribute( 'class' ) . ' mdc-text-field mdc-text-field--filled '. $validation_error_class );
	
				$text_ripple = $dom->createElement( 'div' );
				$text_ripple->setAttribute( 'class', 'mdc-text-field__ripple' );
				$outer_div->appendChild( $text_ripple );

				// $inputs = $item_container->getElementsByTagName( 'input' );
				// foreach( $inputs as $input ){
					$cell_input->setAttribute( 'class', 'mdc-text-field__input' );
					$outer_div->appendChild( $cell_input );
				// }
				stla_material_field_icon( $outer_div, $dom );
				$line_ripple = $dom->createElement( 'div' );
				$line_ripple->setAttribute( 'class', 'mdc-line-ripple' );
				$outer_div->appendChild( $line_ripple );
			}else{

				$outer_div->setAttribute( 'class', $outer_div->getAttribute( 'class' ) . ' mdc-text-field mdc-text-field--outlined '. $validation_error_class );

				$notched_outline = $dom->createElement( 'div' );
				$notched_outline->setAttribute( 'class', 'mdc-notched-outline' );
				$outer_div->appendChild( $notched_outline );

				$outline__leading = $dom->createElement( 'div' );
				$outline__leading->setAttribute( 'class', 'mdc-notched-outline__leading' );
				$notched_outline->appendChild( $outline__leading );

				$outline_notch = $dom->createElement( 'div' );
				$outline_notch->setAttribute( 'class', 'mdc-notched-outline__notch' );
				$notched_outline->appendChild( $outline_notch );

				$outline_trailing = $dom->createElement( 'div' );
				$outline_trailing->setAttribute( 'class', 'mdc-notched-outline__trailing' );
				$notched_outline->appendChild( $outline_trailing );

				$cell_input->setAttribute( 'class', 'mdc-text-field__input' );
				$outer_div->appendChild( $cell_input );

				stla_material_field_icon( $outer_div, $dom );

			}
		}
	}

	// Add class to input
	$get_tds = $dom->getElementsByTagName( 'td' );
	foreach ( $get_tds as $td ) {
		$td_classes = '';

		// Gravity Forms recent version doesn't have 'gfield_list_icons' class instead its empty
		if ( $td_classes !== '' && strpos( $td_classes, 'gfield_list_icons' ) === false ) {
			$container_div = $dom->createElement( 'div' );
			$container_div_classes = $type === 'outlined' ? 'mdc-text-field mdc-text-field--outlined mdc-text-field--no-label': 'mdc-text-field mdc-text-field--filled';
			$container_div->setAttribute( 'class', $container_div_classes );
			$container_div->setAttribute( 'data-mdc-auto-init', 'MDCTextField' );
			$td->appendChild( $container_div );
			$div = $td->getElementsByTagName( 'div' )->item( 0 );
			$div_classes = $div->getAttribute( 'class' );

			if ( strpos( $div_classes, 'mdc-text-field' ) !== false ) {
				$inputs = $td->getElementsByTagName( 'input' );
				foreach ( $inputs as $input ) {
					$input->setAttribute( 'class',
						$input->getAttribute( 'class' ) . ' mdc-text-field__input' );

					// add a span before container 
					$top_ripple_span = $dom->createElement('span');
					$top_ripple_span->setAttribute('class', 'mdc-text-field__ripple');
					$container_div->appendChild($top_ripple_span);

					$div->appendChild( $input );
					if( $type === 'outlined' ) {
						$notched_outline = $dom->createElement('div');
						$notched_outline->setAttribute( 'class', 'mdc-notched-outline' );

						$notched_outline_leading = $dom->createElement( 'div' );
						$notched_outline_leading->setAttribute( 'class', 'mdc-notched-outline__leading' );
						
						$notched_outline_notch = $dom->createElement( 'div' );
						$notched_outline_notch->setAttribute( 'class', 'mdc-notched-outline__notch' );

						$notched_outline_trailing = $dom->createElement( 'div' );
						$notched_outline_trailing->setAttribute( 'class', 'mdc-notched-outline__trailing' );
						
						// if ($contains_placeholder) {
						// 	$notched_outline->setAttribute( 'class', 'mdc-notched-outline mdc-notched-outline--notched' );
						// }
						$container_div->appendChild( $notched_outline );

						$notched_outline->appendChild( $notched_outline_leading );
						$notched_outline->appendChild( $notched_outline_notch );
						$notched_outline->appendChild( $notched_outline_trailing );

						// $label->setAttribute('class', $label->getAttribute( 'class' ) . $add_label_classes );
						// $notched_outline_notch->appendChild( $label );
					}

					//create a new div
                    if ($type === 'filled') {
                        $bottom_line_div = $dom->createElement('div');
                        $bottom_line_div->setAttribute('class', 'mdc-line-ripple');
                        $div->appendChild($bottom_line_div);
                    }
				}
			}
		}
	}
	$content = utf8_decode($dom->saveHTML($dom->documentElement));

}

==> wpackagist-plugin-styles-layouts-material-design-5.0.zip: includes/list.php <==
<?php

/***************************************** for list field **************************************/

if ( $field->type == 'list' ) {


	$content_xpath = new DomXPath($dom);

	$list_groups = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_list_group ')]");

	$list_header_items = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_header_item ') ]");

	$new_item = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_list_container ') ]");

	$field_labels =  $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_label ')]");
	// set class on field labels.
	foreach( $field_labels as $field_label ){
		$label_class = $field_label->getAttribute( 'class' );

		$field_label->setAttribute( 'class', $label_class. ' mdc-typography--subtitle1' );
	}

	// in legacy mode the gravity form is using th instead of classes on heading.
	if( empty( $list_header_items->length ) ){

		$list_header_items = $dom->getElementsByTagName( 'th' );
	}

	// set class on header title in multcolumn list.
	foreach( $list_header_items as $list_header_item ){
		$item_class = $list_header_item->getAttribute( 'class' );

		$list_header_item->setAttribute( 'class', $item_class. ' mdc-typography--subtitle1' );
	}

	$validation_errors = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' validation_message ')]");
	$validation_error_class = '';

	foreach ( $validation_errors as $validation_error ) {
		$validation_error->setAttribute( 'class', $validation_error->getAttribute( 'class' ) . ' mdc-text-field-helper-text mdc-text-field-helper-text--persistent mdc-text-field-helper-text--validation-msg' );

		// error present then set varialbe
		$validation_error_class = 'mdc-text-field--invalid';
	}

	foreach( $list_groups as $list_group ){
		$cell_inputs = $list_group->getElementsByTagName( 'input' );
		
		foreach( $cell_inputs as $cell_input ){
			$item_container = $cell_input->parentNode;
			$outer_div = $dom->createElement( 'div' );
				$outer_div->setAttribute( 'data-mdc-auto-init', 'MDCTextField' );
				$item_container->appendChild( $outer_div );

				

			if( $type === 'filled' ){
				
				$outer_div->setAttribute( 'class', $outer_div->getAttribute( 'class' ) . ' mdc-text-field mdc-text-field--filled '. $validation_error_class );
	
				$text_ripple = $dom->createElement( 'div' );
				$text_ripple->setAttribute( 'class', 'mdc-text-field__ripple' );
				$outer_div->appendChild( $text_ripple );

				// $inputs = $item_container->getElementsByTagName( 'input' );
				// foreach( $inputs as $input ){
					$cell_input->setAttribute( 'class', 'mdc-text-field__input' );
					$outer_div->appendChild( $cell_input );
				// }
				stla_material_field_icon( $outer_div, $dom );
				$line_ripple = $dom->createElement( 'div' );
				$line_ripple->setAttribute( 'class', 'mdc-line-ripple' );
				$outer_div->appendChild( $line_ripple );
			}else{

				$outer_div->setAttribute( 'class', $outer_div->getAttribute( 'class' ) . ' mdc-text-field mdc-text-field--outlined '. $validation_error_class );

				$notched_outline = $dom->createElement( 'div' );
				$notched_outline->setAttribute( 'class', 'mdc-notched-outline' );
				$outer_div->appendChild( $notched_outline );

				$outline__leading = $dom->createElement( 'div' );
				$outline__leading->setAttribute( 'class', 'mdc-notched-outline__leading' );
				$notched_outline->appendChild( $outline__leading );

				$outline_notch = $dom->createElement( 'div' );
				$outline_notch->setAttribute( 'class', 'mdc-notched-outline__notch' );
				$notched_outline->appendChild( $outline_notch );

				$outline_trailing = $dom->createElement( 'div' );
				$outline_trailing->setAttribute( 'class', 'mdc-notched-outline__trailing' );
				$notched_outline->appendChild( $outline_trailing );

				$cell_input->setAttribute( 'class', 'mdc-text-field__input' );
				$outer_div->appendChild( $cell_input );

				stla_material_field_icon( $outer_div, $dom );

			}
		}
	}

	// Add class to input
	$get_tds = $dom->getElementsByTagName( 'td' );
	foreach ( $get_tds as $td ) {
		$td_classes = '';

		// Gravity Forms recent version doesn't have 'gfield_list_icons' class instead its empty
		if ( $td_classes !== '' && strpos( $td_classes, 'gfield_list_icons' ) === false ) {
			$container_div = $dom->createElement( 'div' );
			$container_div_classes = $type === 'outlined' ? 'mdc-text-field mdc-text-field--outlined mdc-text-field--no-label': 'mdc-text-field mdc-text-field--filled';
			$container_div->setAttribute( 'class', $container_div_classes );
			$container_div->setAttribute( 'data-mdc-auto-init', 'MDCTextField' );
			$td->appendChild( $container_div );
			$div = $td->getElementsByTagName( 'div' )->item( 0 );
			$div_classes = $div->getAttribute( 'class' );

			if ( strpos( $div_classes, 'mdc-text-field' ) !== false ) {
				$inputs = $td->getElementsByTagName( 'input' );
				foreach ( $inputs as $input ) {
					$input->setAttribute( 'class',
						$input->getAttribute( 'class' ) . ' mdc-text-field__input' );

					// add a span before container 
					$top_ripple_span = $dom->createElement('span');
					$top_ripple_span->setAttribute('class', 'mdc-text-field__ripple');
					$container_div->appendChild($top_ripple_span);

					$div->appendChild( $input );
					if( $type === 'outlined' ) {
						$notched_outline = $dom->createElement('div');
						$notched_outline->setAttribute( 'class', 'mdc-notched-outline' );

						$notched_outline_leading = $dom->createElement( 'div' );
						$notched_outline_leading->setAttribute( 'class', 'mdc-notched-outline__leading' );
						
						$notched_outline_notch = $dom->createElement( 'div' );
						$notched_outline_notch->setAttribute( 'class', 'mdc-notched-outline__notch' );

						$notched_outline_trailing = $dom->createElement( 'div' );
						$notched_outline_trailing->setAttribute( 'class', 'mdc-notched-outline__trailing' );
						
						// if ($contains_placeholder) {
						// 	$notched_outline->setAttribute( 'class', 'mdc-notched-outline mdc-notched-outline--notched' );
						// }
						$container_div->appendChild( $notched_outline );

						$notched_outline->appendChild( $notched_outline_leading );
						$notched_outline->appendChild( $notched_outline_notch );
						$notched_outline->appendChild( $notched_outline_trailing );

						// $label->setAttribute('class', $label->getAttribute( 'class' ) . $add_label_classes );
						// $notched_outline_notch->appendChild( $label );
					}

					//create a new div
                    if ($type === 'filled') {
                        $bottom_line_div = $dom->createElement('div');
                        $bottom_line_div->setAttribute('class', 'mdc-line-ripple');
                        $div->appendChild($bottom_line_div);
                    }
				}
			}
		}
	}
	$content = utf8_decode($dom->saveHTML($dom->documentElement));

}
